#include <Servo.h>
#include <usbdrv.h>
#include <Wire.h>

Servo sv1,sv2;

static uint8_t SCORE1 = 0;
static uint8_t SCORE2 = 0;

int rst = 0;
int last_sv1 = 0;
int last_sv2 = 0;
int x = 0, y = 0;

#define RQ_RESET 0
#define RQ_SCORE1 1
#define RQ_SCORE2 2

usbMsgLen_t usbFunctionSetup(uint8_t data[8]) {
  usbRequest_t *rq = (usbRequest_t*)data;

  if (rq -> bRequest == RQ_SCORE1) {
    usbMsgPtr = (uint8_t*) &SCORE1;
    return 4;
  }
  else if (rq -> bRequest == RQ_SCORE2) {
    usbMsgPtr = (uint8_t*) &SCORE2;
    return 4;
  }
  else if (rq->bRequest == RQ_RESET) {
    SCORE1 = 0; SCORE2 = 0; //Reset score to 0
    rst = 1;
    return 0;
  }
  return 0;
}

void setup() {
  // put your setup code here, to run once:

  pinMode(PIN_PB2, INPUT_PULLUP);
  pinMode(PIN_PB0, INPUT_PULLUP);
  pinMode(PIN_PB5, OUTPUT);
  sv1.attach(PIN_PB3);
  sv2.attach(PIN_PB1);

  sv1.write(0);
  sv2.write(180);

  usbInit();

  /* enforce re-enumeration of USB devices */
  usbDeviceDisconnect();
  delay(300);
  usbDeviceConnect();
}

void loop() {
  // put your main code here, to run repeatedly:
  usbPoll();

  int i;
  digitalWrite(PIN_PB5, HIGH); //Countdown 3 secs by Buzzer PB5
  for(i = 0; i < 5; i++) {
    usbPoll();
    _delay_ms(40);
  }
  digitalWrite(PIN_PB5, LOW);
  for(i = 0; i < 20; i++) {
    usbPoll();
    _delay_ms(40);
  }
  digitalWrite(PIN_PB5, HIGH);
  for(i = 0; i < 5; i++) {
    usbPoll();
    _delay_ms(40);
  }
  digitalWrite(PIN_PB5, LOW);
  for(i = 0; i < 20; i++) {
    usbPoll();
    _delay_ms(40);
  }
  digitalWrite(PIN_PB5, HIGH);
  for(i = 0; i < 5; i++) {
    usbPoll();
    _delay_ms(40);
  }
  digitalWrite(PIN_PB5, LOW);
  usbPoll();

  while (digitalRead(PIN_PB0) == 1 || digitalRead(PIN_PB2) == 1) { //Detect SW PB0,PB1

    usbPoll();
    if (digitalRead(PIN_PB0) == 0) { //Check state of SW PB0
      x = 0;
      y = 5;
      break;
    }
    else if (digitalRead(PIN_PB2) == 0) { //Check state of SW PB2
      y = 0;
      x = 5;
      break;
    }
    usbPoll();
    if (rst == 1) {
      break;
    }
  }

  if (rst == 1) { //If get RESET request from usb -> return to Countdown state again
    usbPoll();
    rst = 0;
  }

  else {
    usbPoll();
    if (x < y) { //If player1 won -> gain point and drop opponent servo angle degree
      SCORE1++;
      sv2.write(90);

    }
    else { //If player2 won -> gain point and drop opponent servo angle degree
      SCORE2++;
      sv1.write(90);
    }
    usbPoll();

    x = 0; y = 0;
    for(i = 0; i < 25; i++) { //Delay 1 sec
      usbPoll();
      _delay_ms(40);
    }

    usbPoll();
    sv1.write(0); //Set servo angle degree to default
    sv2.write(180); //Set servo angle degree to default

    for(i = 0; i < 25; i++) { //Delay 1 sec
      usbPoll();
      _delay_ms(40);
    }

    while (digitalRead(PIN_PB0) == 0 || digitalRead(PIN_PB0) == 0) { //Check HOLD PRESSED of SW
      usbPoll();
    }
  }

}
